summaryrefslogtreecommitdiffstats
path: root/kdesktop/kcustommenu.cc
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 20:16:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 20:16:47 +0000
commit495d08bc2db58ee7fc4ea55a7158f2f61b82fc56 (patch)
treedaabcb652c07b9a17cad88ca50b63a2d91ead4a3 /kdesktop/kcustommenu.cc
parent50001f1757f97510e80cb1990e2f2d5b00144c2a (diff)
downloadtdebase-495d08bc2db58ee7fc4ea55a7158f2f61b82fc56.tar.gz
tdebase-495d08bc2db58ee7fc4ea55a7158f2f61b82fc56.zip
Automated conversion for enhanced compatibility with TQt for Qt4 3.4.0 TP1
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdebase@1211357 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kdesktop/kcustommenu.cc')
-rw-r--r--kdesktop/kcustommenu.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/kdesktop/kcustommenu.cc b/kdesktop/kcustommenu.cc
index 1d39a093d..2a6b64ec6 100644
--- a/kdesktop/kcustommenu.cc
+++ b/kdesktop/kcustommenu.cc
@@ -81,8 +81,8 @@ KCustomMenu::insertMenuItem(KService::Ptr & s, int nId, int nIndex/*= -1*/)
TQString serviceName = s->name();
// item names may contain ampersands. To avoid them being converted
- // to accelators, replace them with two ampersands.
- serviceName.replace("&", "&&");
+ // to accelators, tqreplace them with two ampersands.
+ serviceName.tqreplace("&", "&&");
TQPixmap normal = KGlobal::instance()->iconLoader()->loadIcon(s->icon(), KIcon::Small,
0, KIcon::DefaultState, 0L, true);